/*
    TIHex v0.41
    Copyright (C) 2004 Jonas Gehring
    This programm uses functions from ExtGraph v2.00beta2 and TIChess by TIChessTeam
        
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

// C Source File
// Created 08.04.04; 17:31:08

#include <tigcclib.h>					// Include all standard header files
#include "tihex.h"						// Include "tihex"-header
#include "extgraph.h"					// Include ExtGraph v2.00beta2 by TIChessTeam

// Fill or clear a field
void _drawcoin(int kind, int xpos, int ypos, int mode)
{
	int color = 1;
	// X-positions of the field
	static int xfield[10][10] = {
										 		 {32, 41, 50, 59, 68, 77, 86, 95, 104, 113},
									     	 {41, 50, 59, 68, 77, 86, 95, 104, 113, 122},
											 	 {50, 59, 68, 77, 86, 95, 104, 113, 122, 131},
									 		 	 {59, 68, 77, 86, 95, 104, 113, 122, 131, 140},
											 	 {68, 77, 86, 95, 104, 113, 122, 131, 140, 149},
											 	 {77, 86, 95, 104, 113, 122, 131, 140, 149, 158},
												 {86, 95, 104, 113, 122, 131, 140, 149, 158, 167},
												 {95, 104, 113, 122, 131, 140, 149, 158, 167, 176},
											 	 {104, 113, 122, 131, 140, 149, 158, 167, 176, 185},
											   {113, 122, 131, 140, 149, 158, 167, 176, 185, 194}								
										 	  };

	// Y-postions of the filed
	static int yfield[10][10] = {
												 {58, 54, 50, 46, 42, 38, 34, 30, 26, 22},
												 {62, 58, 54, 50, 46, 42, 38, 34, 30, 26},
												 {66, 62, 58, 54, 50, 46, 42, 38, 34, 30},
												 {70, 66, 62, 58, 54, 50, 46, 42, 38, 34},
												 {74, 70, 66, 62, 58, 54, 50, 46, 42, 38},
												 {78, 74, 70, 66, 62, 58, 54, 50, 46, 42},
												 {82, 78, 74, 70, 66, 62, 58, 54, 50, 46},
												 {86, 82, 78, 74, 70, 66, 62, 58, 54, 50},
											 	 {90, 86, 82, 78, 74, 70, 66, 62, 58, 54},												
											 	 {94, 90, 86, 82, 78, 74, 70, 66, 62, 58}								
											 };
	
	// React on parameter 'mode' and 'kind'
	switch (mode)
	{
		case CLEAR:
			color = COLOR_LIGHTGRAY;
			break;
		case DRAW:	
			if (kind == PLAYER_1)
				color = COLOR_DARKGRAY;
			else
				color = COLOR_WHITE;
			break;
		case FULL:
			color = COLOR_BLACK;
			break;
	}

	// Fill a hex with color
	FastDrawGrayLine(xfield[xpos][ypos], yfield[xpos][ypos], xfield[xpos][ypos]+11, yfield[xpos][ypos], color);
	FastDrawGrayLine(xfield[xpos][ypos]+1, yfield[xpos][ypos]+1, xfield[xpos][ypos]+10, yfield[xpos][ypos]+1, color);
	FastDrawGrayLine(xfield[xpos][ypos]+1, yfield[xpos][ypos]-1, xfield[xpos][ypos]+10, yfield[xpos][ypos]-1, color);
	FastDrawGrayLine(xfield[xpos][ypos]+2, yfield[xpos][ypos]+2, xfield[xpos][ypos]+9, yfield[xpos][ypos]+2, color);
	FastDrawGrayLine(xfield[xpos][ypos]+2, yfield[xpos][ypos]-2, xfield[xpos][ypos]+9, yfield[xpos][ypos]-2, color);
	FastDrawGrayLine(xfield[xpos][ypos]+3, yfield[xpos][ypos]+3, xfield[xpos][ypos]+8, yfield[xpos][ypos]+3, color);
	FastDrawGrayLine(xfield[xpos][ypos]+3, yfield[xpos][ypos]-3, xfield[xpos][ypos]+8, yfield[xpos][ypos]-3, color);
}


// Display the player number
void _nsprite(int num)
{
	// Delete old number
	DrawGrayRect(223, 0, 240, 10, COLOR_LIGHTGRAY, RECT_FILLED);
	
	// Draw number at the upper left corner
	if (num == PLAYER_1)
		GraySprite16_OR(223, 1 , NUM_HEIGHT, num1light, num1dark, GetPlane(LIGHT_PLANE), GetPlane(DARK_PLANE));
	else
		GraySprite16_OR(223, 1 , NUM_HEIGHT, num2light, num2dark, GetPlane(LIGHT_PLANE), GetPlane(DARK_PLANE));
}


// Kind of "minimizing" effect (slightly modified, taken from TIChess by the TIChessTeam)
void _startend(void) {
    short height  = 128;
    short height2 = height/2;
    short width   = 240;
    short width2  = width/2;
    short i;
    volatile short j;

    height--;
    width--;

    //---------------------
    // clear in y direction
    //---------------------

    for (i=0;i<height2;i++) {
        DrawGrayLine(0,i,width,i,COLOR_BLACK);
        DrawGrayLine(0,height-i,width,height-i,COLOR_BLACK);
        if (i) {
           DrawGrayLine(0,i-1,width,i-1,COLOR_WHITE);
           DrawGrayLine(0,height-i+1,width,height-i+1,COLOR_WHITE);
        }
        for (j=0;j<=1900;j++);
    }

    DrawGrayLine(0,height2-1,width,height2-1,COLOR_WHITE);

    //-----------------------------
    // clear in x direction
    //-----------------------------
    for (i=0;i<=width2;i++) {
        DrawPix(i,height2,A_REVERSE);
        DrawPix(width-i,height2,A_REVERSE);
        for (j=0;j<=1100;j++);
    }
}


// Draws the a rectangle for messages/menu with the height 'high'
void _drawrect(int high)
{
	int y0 = (128/2) - (high/2), y1 = (128/2) + (high/2);
	int i;
	
	for (i = 120; i >= 50; i--)
	{ 
		DrawGrayLine(i, y0-3, i, y1+3, COLOR_WHITE);
		DrawGrayLine(i, y0-2, i, y1+2, COLOR_DARKGRAY);
		DrawGrayLine(i, y0, i, y1, COLOR_BLACK);
	
		DrawGrayLine(241-i, y0-3, 241-i, y1+3, COLOR_WHITE);
		DrawGrayLine(241-i, y0-2, 241-i, y1+2, COLOR_DARKGRAY);
		DrawGrayLine(241-i, y0, 241-i, y1, COLOR_BLACK);
	}
	
	DrawGrayLine(49, y0-2, 49, y1+2, COLOR_DARKGRAY);
	DrawGrayLine(241-49, y0-2 , 241-49, y1+2, COLOR_DARKGRAY);
	DrawGrayLine(48, y0-2, 48, y1+2, COLOR_DARKGRAY);
	DrawGrayLine(241-48, y0-2 , 241-48, y1+2, COLOR_DARKGRAY);
	
	DrawGrayLine(47, y0-3, 47, y1+3, COLOR_WHITE);
	DrawGrayLine(241-47, y0-3 , 241-47, y1+3, COLOR_WHITE);
	DrawGrayLine(48, y0-3, 241-48, y0-3, COLOR_WHITE);
	DrawGrayLine(48, y1+3, 241-48, y1+3, COLOR_WHITE);
	
	// Draw the title ("TIHex") and the icons
	DrawGrayStrExt(0, y0+4, TITLE, A_REVERSE | A_CENTERED, MEDIUM);	
	GraySprite8_AND(93, y0+5, NUM_HEIGHT, icon1light, icon1dark, GetPlane(LIGHT_PLANE), GetPlane(DARK_PLANE));
	GraySprite8_AND(140, y0+5, NUM_HEIGHT, icon2light, icon2dark, GetPlane(LIGHT_PLANE), GetPlane(DARK_PLANE));

}







